@@ -21,6 +21,7 @@ import (
 	uns "k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	types "k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
+	utilnet "k8s.io/utils/net"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 )
 
@@ -30,6 +31,7 @@ const OVN_NB_RAFT_PORT = "9643"
 const OVN_SB_RAFT_PORT = "9644"
 const CLUSTER_CONFIG_NAME = "cluster-config-v1"
 const CLUSTER_CONFIG_NAMESPACE = "kube-system"
+const OVN_CERT_CN = "ovn"
 
 // renderOVNKubernetes returns the manifests for the ovn-kubernetes.
 // This creates
@@ -47,6 +49,7 @@ func renderOVNKubernetes(conf *operv1.NetworkSpec, bootstrapResult *bootstrap.Bo
 	data := render.MakeRenderData()
 	data.Data["ReleaseVersion"] = os.Getenv("RELEASE_VERSION")
 	data.Data["OvnImage"] = os.Getenv("OVN_IMAGE")
+	data.Data["KubeRBACProxyImage"] = os.Getenv("KUBE_RBAC_PROXY_IMAGE")
 	data.Data["KUBERNETES_SERVICE_HOST"] = os.Getenv("KUBERNETES_SERVICE_HOST")
 	data.Data["KUBERNETES_SERVICE_PORT"] = os.Getenv("KUBERNETES_SERVICE_PORT")
 	data.Data["K8S_APISERVER"] = fmt.Sprintf("https://%s:%s", os.Getenv("KUBERNETES_SERVICE_HOST"), os.Getenv("KUBERNETES_SERVICE_PORT"))
@@ -66,6 +69,8 @@ func renderOVNKubernetes(conf *operv1.NetworkSpec, bootstrapResult *bootstrap.Bo
 	data.Data["OVN_MASTER_IP"] = bootstrapResult.OVN.MasterIPs[0]
 	data.Data["OVN_MIN_AVAILABLE"] = len(bootstrapResult.OVN.MasterIPs)/2 + 1
 	data.Data["LISTEN_DUAL_STACK"] = listenDualStack(bootstrapResult.OVN.MasterIPs[0])
+	data.Data["OVN_CERT_CN"] = OVN_CERT_CN
+	data.Data["OVN_NORTHD_PROBE_INTERVAL"] = os.Getenv("OVN_NORTHD_PROBE_INTERVAL")
 
 	var ippools string
 	for _, net := range conf.ClusterNetwork {
@@ -91,10 +96,16 @@ func renderOVNKubernetes(conf *operv1.NetworkSpec, bootstrapResult *bootstrap.Bo
 		} else {
 			data.Data["OVNHybridOverlayNetCIDR"] = ""
 		}
-		data.Data["OVNHybridOverlayEnable"] = "true"
+		if c.HybridOverlayConfig.HybridOverlayVXLANPort != nil {
+			data.Data["OVNHybridOverlayVXLANPort"] = c.HybridOverlayConfig.HybridOverlayVXLANPort
+		} else {
+			data.Data["OVNHybridOverlayVXLANPort"] = ""
+		}
+		data.Data["OVNHybridOverlayEnable"] = true
 	} else {
 		data.Data["OVNHybridOverlayNetCIDR"] = ""
-		data.Data["OVNHybridOverlayEnable"] = ""
+		data.Data["OVNHybridOverlayEnable"] = false
+		data.Data["OVNHybridOverlayVXLANPort"] = ""
 	}
 
 	manifests, err := render.RenderDir(filepath.Join(manifestDir, "network/ovn-kubernetes"), &data)
@@ -111,11 +122,35 @@ func renderOVNKubernetes(conf *operv1.NetworkSpec, bootstrapResult *bootstrap.Bo
 func validateOVNKubernetes(conf *operv1.NetworkSpec) []error {
 	out := []error{}
 
-	if len(conf.ClusterNetwork) == 0 {
-		out = append(out, errors.Errorf("ClusterNetworks cannot be empty"))
+	var cnHasIPv4, cnHasIPv6 bool
+	for _, cn := range conf.ClusterNetwork {
+		if utilnet.IsIPv6CIDRString(cn.CIDR) {
+			cnHasIPv6 = true
+		} else {
+			cnHasIPv4 = true
+		}
 	}
-	if len(conf.ServiceNetwork) != 1 {
-		out = append(out, errors.Errorf("ServiceNetwork must have exactly 1 entry"))
+	if !cnHasIPv6 && !cnHasIPv4 {
+		out = append(out, errors.Errorf("ClusterNetwork cannot be empty"))
+	}
+
+	var snHasIPv4, snHasIPv6 bool
+	for _, sn := range conf.ServiceNetwork {
+		if utilnet.IsIPv6CIDRString(sn) {
+			snHasIPv6 = true
+		} else {
+			snHasIPv4 = true
+		}
+	}
+	if !snHasIPv6 && !snHasIPv4 {
+		out = append(out, errors.Errorf("ServiceNetwork cannot be empty"))
+	}
+
+	if cnHasIPv4 != snHasIPv4 || cnHasIPv6 != snHasIPv6 {
+		out = append(out, errors.Errorf("ClusterNetwork and ServiceNetwork must have matching IP families"))
+	}
+	if len(conf.ServiceNetwork) > 2 || (len(conf.ServiceNetwork) == 2 && (!snHasIPv4 || !snHasIPv6)) {
+		out = append(out, errors.Errorf("ServiceNetwork must have either a single CIDR or a dual-stack pair of CIDRs"))
 	}
 
 	oc := conf.DefaultNetwork.OVNKubernetesConfig
@@ -207,7 +242,7 @@ func boostrapOVN(kubeClient client.Client) (*bootstrap.BootstrapResult, error) {
 
 	controlPlaneReplicaCount, _ := strconv.Atoi(rcD.ControlPlane.Replicas)
 
-	err := wait.PollImmediate(2*time.Second, 60*time.Second, func() (bool, error) {
+	err := wait.PollImmediate(5*time.Second, 280*time.Second, func() (bool, error) {
 		matchingLabels := &client.MatchingLabels{"node-role.kubernetes.io/master": ""}
 		if err := kubeClient.List(context.TODO(), masterNodeList, matchingLabels); err != nil {
 			return false, err
